## example code for LDAP auth
# requires python 2.7 and python-ldap (http://python-ldap.org)

import ldap
import ldap.sasl

servers = ["ldap://dc1.labs.wmi.amu.edu.pl", "ldap://dc2.labs.wmi.amu.edu.pl"]
suffix =  "@labs.wmi.amu.edu.pl";
port = 636;
root = "DC=labs,DC=wmi,DC=amu,DC=edu,DC=pl";

# user credentials
login = ""
password = ""

class LdapQuery():
    def __init__(self, servers, port, root):
        self.servers = servers
        self.root = "OU=Students,OU=People," + root

        ldap.PORT = port

        # cert path
        ldap.set_option(ldap.OPT_X_TLS_CACERTFILE, "./ca_labs.wmi.amu.edu.pl.pem")

        for i in range(len(self.servers)):
            try:
                self.ldap_handler = ldap.initialize(self.servers[i])
                break
            except ldap.SERVER_DOWN, e:
                print e

        self.ldap_handler.set_option(ldap.OPT_X_TLS_DEMAND, True)
        self.ldap_handler.start_tls_s()

    def search_user(self, login):
        return self.ldap_handler.search_s(
                    self.root,
                    ldap.SCOPE_SUBTREE,
                    'cn=' + login,
                    ['givenname', 'sn', 'mail'])

    def bind(self, login=None, passwd=None):
        try:
            if passwd:
                # authorized
                try:
                    return self.ldap_handler.simple_bind_s(login, passwd)
                except ldap.INVALID_CREDENTIALS:
                    print "Invalid credentials"
                    exit(1)
            else:
                # anonymous
                return self.ldap_handler.bind_s('','', ldap.AUTH_SIMPLE)
        except ldap.LDAPError, e:
            return e

if __name__ == "__main__":
    try:
        ldapquery = LdapQuery(servers, port, root)

        # bind session to server
        ldapquery.bind(login+suffix, password)

        print ldapquery.search_user(login)
        print ldapquery.ldap_handler.whoami_s()

    except ldap.LDAPError, e:
        print e

